DataStream

Struct DataStream 

pub struct DataStream<T> { /* private fields */ }
A stream that allows endian-aware read and write.

This struct is generic over any type T that implements some combination of Read, Write, and Seek. Methods are conditionally available based on the traits implemented by T.

Implementations

Source

impl<T> DataStream<T>

pub const fn new(inner: T, endian: Endian) -> Self

Creates a new DataStream with the given inner stream and endianness.